@@ -21,6 +21,10 @@ use constant NumberOfBillingCyclesCannotBeBlank                 => "91912";
 use constant NumberOfBillingCyclesIsTooSmall                    => "91909";
 use constant NumberOfBillingCyclesMustBeGreaterThanZero         => "91907";
 use constant NumberOfBillingCyclesMustBeNumeric                 => "91906";
+use constant PaymentMethodNonceCardTypeIsNotAccepted            => "91924";
+use constant PaymentMethodNonceIsInvalid                        => "91925";
+use constant PaymentMethodNonceNotAssociatedWithCustomer        => "91926";
+use constant PaymentMethodNonceUnvaultedCardIsNotAccepted       => "91927";
 use constant PaymentMethodTokenCardTypeIsNotAccepted            => "91902";
 use constant PaymentMethodTokenIsInvalid                        => "91903";
 use constant PaymentMethodTokenNotAssociatedWithCustomer        => "91905";
