@@ -27,6 +27,9 @@ $field->text("customer_website");
 $field->text("id");
 $field->text("order_id");
 $field->text("payment_method_token");
+$field->text("paypal_payment_id");
+$field->text("paypal_authorization_id");
+$field->text("paypal_payer_email");
 $field->text("processor_authorization_code");
 $field->text("settlement_batch_id");
 $field->text("shipping_company");
